# Forward Collision Warning - service part

Early collision warning Network Application for Transportation use case - service part.
The package contains core modules for Forward Collision Warning Network Application for 5G-ERA.


